@@ -100,7 +100,9 @@ def get_configure_commands(source: pathlib.Path, destination: pathlib.Path,
 
         commands.append(["make", "-C", str(source.absolute()), "update"])
 
-    commands.append(['cmake', '-S' + str(source.absolute()), 
+    commands.append(['cmake', 
+                     ('-H' if 
+                      platform.system() != "Linux" else "") + str(source.absolute()), 
                     '-B' + str(destination.absolute()),
                     '-DWITH_PLAYER=OFF', '-DWITH_PYTHON_INSTALL=OFF',
                     '-DWITH_PYTHON_MODULE=ON', 
